# cropwiseworker
# changelog

All noticeable changes to this project will be documented in this file.

The format is based on [Keep a Changelog] (https://keepachangelog.com/en/1.0.0/), and this project adheres to [Semantic Versioning] (https://semver.org/spec/v2.0.0.html).

## [0.0.6] – 2024-07-16

### Added 
- Added a new function `fetch_changes` for mass loading of changed object from Cropwise Operations.

### Changed
– The README.md

### Fixed
– The bug with previous version downloading.

## [0.0.5] – 2024-07-08

### Added 
- Added a new function `create_orchard_rows` for geofencing.

## [0.0.2] - 2024-04-12

### Added
- The project was created.
- Added the function `data_downloader` for mass loading of data on the Cropwise Operations API.
- Added the function `agrimatrix_dataset` for creating an Agrimatrix report.
- Integration with the external Cropwise Operations API.

